@@ -52,10 +52,10 @@ setMethod(applyPileups, c("PileupFiles", "missing"),
 setMethod(show, "PileupFiles", function(object) {
     cat("class:", class(object), "\n")
     nms <- names(object)
-    txt <- paste(BiocGenerics:::selectSome(nms, 3L), collapse=", ")
+    txt <- paste(S4Vectors:::selectSome(nms, 3L), collapse=", ")
     cat(sprintf("names: %s (%d total)\n", txt, length(nms)))
     fls <- sapply(object, function(x) basename(path(x)))
-    txt <- paste(BiocGenerics:::selectSome(fls, 3L), collapse=", ")
+    txt <- paste(S4Vectors:::selectSome(fls, 3L), collapse=", ")
     cat(sprintf("plpFiles: %s (%d total)\n", txt, length(fls)))
     cat("plpParam: class", class(plpParam(object)), "\n")
 })
