@@ -25,14 +25,16 @@ bgzipTabix <-
 }
 
 bgzip <-
-    function(file, dest = sprintf("%s.gz", file), overwrite=FALSE)
+    function(file, dest = sprintf("%s.bgz", sub("\\.gz$", "", file)),
+             overwrite=FALSE)
 {
     .zip(.bgzip, file, dest, overwrite)
 }
 
 
 razip <-
-    function(file, dest = sprintf("%s.rz", file), overwrite=FALSE)
+    function(file, dest = sprintf("%s.rz", sub("\\.gz$", "", file)),
+             overwrite=FALSE)
 {
     .zip(.razip, file, dest, overwrite)
 }
