@@ -3,6 +3,6 @@
 
 #include <Rinternals.h>
 
-SEXP as_bam(SEXP file, SEXP destination);
+SEXP as_bam(SEXP file, SEXP destination, SEXP binary);
 
 #endif                          /* _AS_BAM_H_ */
