@@ -24,8 +24,8 @@ void _Free_SCAN_BAM_DATA(SCAN_BAM_DATA sbd);
 int _grow_SCAN_BAM_DATA(BAM_DATA bd, int len);
 void _finish1range_SCAN_BAM_DATA(SCAN_BAM_DATA sbd, bam_header_t *header,
 				 int irange);
-
-SEXP _scan_bam_result_init(SEXP template_list, SEXP names, SEXP space);
+SEXP _scan_bam_result_init(SEXP template_list, SEXP names, SEXP space,
+                           BAM_FILE bfile);
 SEXP _get_or_grow_SCAN_BAM_DATA(BAM_DATA bd, int len);
 
 #endif
